async function fetchImageSize(url) {
  return new Promise((resolve) => {
    const img = new Image();
    img.onload = () => {
      resolve({ width: img.width, height: img.height });
    };
    img.onerror = () => {
      resolve(null);
    };
    img.src = url;
  });
}

async function filterImages(images, onlyFromUrl, minWidth, minHeight, excludedImages) {
  const filteredImages = [];

  for (const img of images) {
    if (excludedImages.has(img.src)) continue;

    if (onlyFromUrl && !img.src.startsWith('http')) {
      continue;
    }

    const size = await fetchImageSize(img.src);
    if (size && size.width >= minWidth && size.height >= minHeight) {
      filteredImages.push(img);
    }
  }

  return filteredImages;
}

function updatePreview(onlyFromUrl, minWidth, minHeight, excludedImages) {
  const images = Array.from(document.images);
  filterImages(images, onlyFromUrl, minWidth, minHeight, excludedImages).then(filteredImages => {
    const urls = filteredImages.map(img => img.src);

    chrome.runtime.sendMessage({
      action: 'showPreview',
      images: urls
    });
  });
}

chrome.runtime.onMessage.addListener((message) => {
  if (message.action === 'downloadImages') {
    const images = Array.from(document.images);
    const excludedImages = new Set(message.excludedImages);
    filterImages(images, message.onlyFromUrl, message.minWidth, message.minHeight, excludedImages).then(filteredImages => {
      const urls = filteredImages.map(img => img.src);

      chrome.runtime.sendMessage({
        action: 'download',
        urls: urls,
        folderName: message.folderName
      });
    });
  }

  if (message.action === 'updatePreview') {
    const excludedImages = new Set();
    updatePreview(message.onlyFromUrl, message.minWidth, message.minHeight, excludedImages);
  }
});
