document.addEventListener('DOMContentLoaded', () => {
  // Load settings from localStorage
  const onlyFromUrlCheckbox = document.getElementById('onlyFromUrl');
  const minWidthInput = document.getElementById('minWidth');
  const minHeightInput = document.getElementById('minHeight');
  const folderNameInput = document.getElementById('folderName');
  let excludedImages = new Set();

  onlyFromUrlCheckbox.checked = localStorage.getItem('onlyFromUrl') === 'true';
  minWidthInput.value = localStorage.getItem('minWidth') || 0;
  minHeightInput.value = localStorage.getItem('minHeight') || 0;
  folderNameInput.value = localStorage.getItem('folderName') || 'images';

  // Update preview on settings change
  const updatePreview = () => {
    const onlyFromUrl = onlyFromUrlCheckbox.checked;
    const minWidth = parseInt(minWidthInput.value, 10);
    const minHeight = parseInt(minHeightInput.value, 10);

    chrome.tabs.query({ active: true, currentWindow: true }, (tabs) => {
      chrome.tabs.sendMessage(tabs[0].id, {
        action: 'updatePreview',
        onlyFromUrl,
        minWidth,
        minHeight
      });
    });
  };

  onlyFromUrlCheckbox.addEventListener('change', () => {
    localStorage.setItem('onlyFromUrl', onlyFromUrlCheckbox.checked);
    excludedImages.clear();
    updatePreview();
  });

  minWidthInput.addEventListener('input', () => {
    localStorage.setItem('minWidth', minWidthInput.value);
    excludedImages.clear();
    updatePreview();
  });

  minHeightInput.addEventListener('input', () => {
    localStorage.setItem('minHeight', minHeightInput.value);
    excludedImages.clear();
    updatePreview();
  });

  document.getElementById('downloadBtn').addEventListener('click', () => {
    const onlyFromUrl = onlyFromUrlCheckbox.checked;
    const minWidth = parseInt(minWidthInput.value, 10);
    const minHeight = parseInt(minHeightInput.value, 10);
    const folderName = folderNameInput.value;

    localStorage.setItem('folderName', folderName);

    chrome.tabs.query({ active: true, currentWindow: true }, (tabs) => {
      chrome.tabs.sendMessage(tabs[0].id, {
        action: 'downloadImages',
        onlyFromUrl,
        minWidth,
        minHeight,
        folderName,
        excludedImages: Array.from(excludedImages)
      });
    });
  });

  const updatePreviewCount = (count) => {
    document.getElementById('previewCount').innerText = `Preview Count: ${count}`;
  };

  const addPreviewListeners = () => {
    document.querySelectorAll('.preview').forEach(img => {
      img.addEventListener('click', () => {
        img.classList.toggle('excluded');
        if (img.classList.contains('excluded')) {
          excludedImages.add(img.src);
        } else {
          excludedImages.delete(img.src);
        }
      });
    });
  };

  // Initial preview update
  updatePreview();

  chrome.runtime.onMessage.addListener((message) => {
    if (message.action === 'showPreview') {
      const previewContainer = document.getElementById('preview');
      previewContainer.innerHTML = '';
      message.images.forEach((src) => {
        const img = document.createElement('img');
        img.src = src;
        img.className = 'preview';
        previewContainer.appendChild(img);
      });
      updatePreviewCount(message.images.length);
      addPreviewListeners();
    }
  });
});
